You are viewing a plain text version of this content. The canonical link for it is here.
Posted to server-dev@james.apache.org by no...@apache.org on 2006/05/06 22:53:32 UTC

svn commit: r400369 - in /james/server/trunk/src/java/org/apache/james/core: AbstractJamesHandler.java AbstractJamesService.java

Author: noel
Date: Sat May  6 13:53:30 2006
New Revision: 400369

URL: http://svn.apache.org/viewcvs?rev=400369&view=rev
Log:
Make the comments match the fact that this is now generic code.

Modified:
    james/server/trunk/src/java/org/apache/james/core/AbstractJamesHandler.java
    james/server/trunk/src/java/org/apache/james/core/AbstractJamesService.java

Modified: james/server/trunk/src/java/org/apache/james/core/AbstractJamesHandler.java
URL: http://svn.apache.org/viewcvs/james/server/trunk/src/java/org/apache/james/core/AbstractJamesHandler.java?rev=400369&r1=400368&r2=400369&view=diff
==============================================================================
--- james/server/trunk/src/java/org/apache/james/core/AbstractJamesService.java (original)
+++ james/server/trunk/src/java/org/apache/james/core/AbstractJamesService.java Sat May  6 13:53:30 2006
@@ -163,7 +163,7 @@
 
 
     /**
-     * The pool used to provide POP3 Handler objects
+     * The pool used to provide Protocol Handler objects
      */
     protected Pool theHandlerPool = null;
 



---------------------------------------------------------------------
To unsubscribe, e-mail: server-dev-unsubscribe@james.apache.org
For additional commands, e-mail: server-dev-help@james.apache.org


Re: svn commit: r400369 - in /james/server/trunk/src/java/org/apache/james/core: AbstractJamesHandler.java AbstractJamesService.java

Posted by Stefano Bagnara <ap...@bago.org>.
noel@apache.org wrote:
> Author: noel
> Date: Sat May  6 13:53:30 2006
> New Revision: 400369
> 
> URL: http://svn.apache.org/viewcvs?rev=400369&view=rev
> Log:
> Make the comments match the fact that this is now generic code.


Thank you Noel,

btw, this is work-in-progress.
I preferred to commit it step-by-step so we keep more clear the 
refactoring path.

Stefano

PS: I started this new refactoring but we can try to release the 
"build_2.3.0_A2" version I tagged/built yesterday. Let me know if you 
want to make a signed release or if I should resubmit the vote.


---------------------------------------------------------------------
To unsubscribe, e-mail: server-dev-unsubscribe@james.apache.org
For additional commands, e-mail: server-dev-help@james.apache.org
--- james/server/trunk/src/java/org/apache/james/core/AbstractJamesHandler.java (original)
+++ james/server/trunk/src/java/org/apache/james/core/AbstractJamesHandler.java Sat May  6 13:53:30 2006
@@ -38,7 +38,7 @@
     protected Thread handlerThread;
 
     /**
      * The TCP/IP socket over which the POP3 interaction
      * is occurring
      */
     protected Socket socket;
@@ -86,7 +86,7 @@
      */
     void idleClose() {
         if (getLogger() != null) {
-            getLogger().error("POP3 Connection has idled out.");
+            getLogger().error("Service Connection has idled out.");
         }
         try {
             if (socket != null) {
@@ -110,7 +110,7 @@
 
     /**
      * This method logs at a "DEBUG" level the response string that
      * was sent to the POP3 client.  The method is provided largely
      * as syntactic sugar to neaten up the code base.  It is declared
      * private and final to encourage compiler inlining.
      *
@@ -38,7 +38,7 @@
 
     /**
-     * The TCP/IP socket over which the POP3 interaction
+     * The TCP/IP socket over which the service interaction
      * is occurring
      */
@@ -110,7 +110,7 @@
     /**
      * This method logs at a "DEBUG" level the response string that
-     * was sent to the POP3 client.  The method is provided largely
+     * was sent to the service client.  The method is provided largely
      * as syntactic sugar to neaten up the code base.  It is declared
      * private and final to encourage compiler inlining.

Modified: james/server/trunk/src/java/org/apache/james/core/AbstractJamesService.java
URL: http://svn.apache.org/viewcvs/james/server/trunk/src/java/org/apache/james/core/AbstractJamesService.java?rev=400369&r1=400368&r2=400369&view=diff
==============================================================================